@@ -1,22 +1,8 @@
 /*
     This file is part of Knights, a chess board for KDE SC 4.
-    Copyright 2009,2010,2011  Miha Čančula <miha@noughmad.eu>
+    SPDX-FileCopyrightText: 2009, 2010, 2011 Miha Čančula <miha@noughmad.eu>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License or (at your option) version 3 or any later version
-    accepted by the membership of KDE e.V. (or its successor approved
-    by the membership of KDE e.V.), which shall act as a proxy
-    defined in Section 14 of version 3 of the license.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "proto/ficsprotocol.h"
@@ -140,12 +126,7 @@ void FicsProtocol::init (  ) {
 	int port = attribute("port").toInt();
 	if ( port == 0 )
 		port = 5000;
-#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
-	connect ( socket, &QTcpSocket::errorOccurred,
-#else
-	connect ( socket, static_cast<void (QTcpSocket::*)(QAbstractSocket::SocketError)> (&QTcpSocket::error),
-#endif
-	          this, &FicsProtocol::socketError );
+    connect ( socket, &QTcpSocket::errorOccurred, this, &FicsProtocol::socketError );
 
 	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 	socket->connectToHost(address, port);
@@ -570,3 +551,5 @@ void FicsProtocol::makeOffer(const Offer& offer) {
 		break;
 	}
 }
+
+#include "moc_ficsprotocol.cpp"
